function zmIsEmpty(val) {
    return 'undefined' === typeof val
        || val === null
        || val === '';
}
function zmGetCookie(name) {
    let cookiesArray = document.cookie.split(';');
    for (let cookie of cookiesArray) {
        let cookiePair = cookie.trim().split('=');
        if (decodeURIComponent(cookiePair[0]) === name) {
            return decodeURIComponent(cookiePair[1]);
        }
    }

    return null;
}
function zmSetCookie(name, value, options = {}) {

    options = {
        path: '/',
        ...options
    };

    let cookie = encodeURIComponent(name) + '=' + encodeURIComponent(value);
    for (let optionKey in options) {
        cookie += '; ' + optionKey;
        let optionValue = options[optionKey];
        if (optionValue !== true) {
            cookie += '=' + optionValue;
        }
    }

    document.cookie = cookie;
}
function zmTrack()
{
    let location = window.location.toString();
    let shopRegex = /^(https?):\/\/([^\/?#:]+)/i;
    let matches = location.match(shopRegex);

    let scheme = matches && matches[1];
    let shopUrl = matches && matches[2];

    let sessionID = zmGetCookie('zmSessionID');
    let userID = zmGetCookie('zmUserID');

    let host = window.zmApi.host + '/';

    var req = new XMLHttpRequest();
    req.onreadystatechange = function () {
        if (this.readyState === 4) {
            let response = JSON.parse(this.responseText);
            if (this.status === 200 || this.status === 201) {
                sessionID = zmGetCookie('zmSessionID');
                if (zmIsEmpty(sessionID)) {
                    sessionID = response.sessionID;
                    zmSetCookie('zmSessionID', sessionID);
                }
                userID = zmGetCookie('zmUserID');
                if (zmIsEmpty(userID)) {
                    userID = response.userID;
                    zmSetCookie('zmUserID', userID);
                }
            } else {
                alert(response.error);
            }
        }
    };
    let getParams = new URLSearchParams();
    getParams.append('url', shopUrl);
    getParams.append('scheme', scheme);
    if (!zmIsEmpty(sessionID)) {
        getParams.append('sessionID', sessionID);
    }
    req.open("GET", host + 'getSettings?' + getParams.toString(), false);
    req.withCredentials = true;
    req.send();


    let eventType = 'page';
    let productID = null;
    let productName = null;
    let productPrice = null;
    let cartHash = null;

    if (!zmIsEmpty(window.zmProduct)) {
        productID = window.zmProduct.id;
        productName = window.zmProduct.name;
        productPrice = window.zmProduct.price * 100;
        eventType = 'product';
    }

    let params = new URLSearchParams();
    params.append('type', 'woocommerce');
    params.append('shopID', shopUrl);
    params.append('apiKey', window.zmApi.key);
    params.append('shopUrl', shopUrl);
    params.append('scheme', scheme);
    params.append('url', location);
    params.append('title', document.title);
    params.append('sessionID', sessionID);
    params.append('userID', userID);

    if (!zmIsEmpty(productID)) {
        params.append('productID', productID);
    }

    if (!zmIsEmpty(productName)) {
        params.append('productName', productName);
    }

    if (!zmIsEmpty(productPrice)) {
        params.append('productPrice', productPrice);
    }

    if (!zmIsEmpty(eventType)) {
        params.append('eventType', eventType);
    }

    cartHash = zmGetCookie('woocommerce_cart_hash');
    if (!zmIsEmpty(cartHash)) {
        params.append('cartID', cartHash);
    }

    req.onreadystatechange = function () {
        if (this.readyState === 4) {
            let response = JSON.parse(this.responseText);
            if (this.status !== 200 && this.status !== 201) {
                alert(response.error);
            }
        }
    };
    req.open("GET", host + 'storeEvent?' + params.toString(), false);
    req.withCredentials = true;
    req.send(params);
}
jQuery(document).ready(function () {
    zmTrack();
    jQuery(document.body).on('update_checkout', function() {
        let values = jQuery('form[name="checkout"]').serializeArray();
        let cartHash = zmGetCookie('woocommerce_cart_hash');
        if (!zmIsEmpty(cartDetails)) {

            let eventType = 'checkout';
            let productID = null;
            let productName = null;
            let productPrice = null;
            let cartHash = null;

            let location = window.location.toString();
            let shopRegex = /^(https?):\/\/([^\/?#:]+)/i;
            let matches = location.match(shopRegex);

            let scheme = matches && matches[1];
            let shopUrl = matches && matches[2];

            let sessionID = zmGetCookie('zmSessionID');
            let userID = zmGetCookie('zmUserID');

            let host = window.zmApi.host + '/';

            let params = new URLSearchParams();
            params.append('type', 'woocommerce');
            params.append('apiKey', window.zmApi.key);
            params.append('shopID', shopUrl);
            params.append('shopUrl', shopUrl);
            params.append('scheme', scheme);
            params.append('url', location);
            params.append('title', document.title);
            params.append('sessionID', sessionID);
            params.append('userID', userID);

            if (!zmIsEmpty(productID)) {
                params.append('productID', productID);
            }

            if (!zmIsEmpty(productName)) {
                params.append('productName', productName);
            }

            if (!zmIsEmpty(productPrice)) {
                params.append('productPrice', productPrice);
            }

            if (!zmIsEmpty(eventType)) {
                params.append('eventType', eventType);
            }

            cartHash = zmGetCookie('woocommerce_cart_hash');
            if (!zmIsEmpty(cartHash)) {
                params.append('cartID', cartHash);
            }

            let checkoutDetails = {
                line_items: cartDetails,
                cartHash: cartHash,
                sessionID: sessionID,
                userID: userID
            };
            if (!zmIsEmpty(values)) {
                for (let field of values) {
                    checkoutDetails[field.name] = field.value;
                }
            }

            // console.log(cartHash, checkoutDetails, window.zmApi, cartDetails);

            var req = new XMLHttpRequest();
            req.onreadystatechange = function () {
                if (this.readyState === 4) {
                    let response = JSON.parse(this.responseText);
                    if (this.status !== 200 && this.status !== 201) {
                        alert(response.error);
                    }
                }
            };
            req.open("POST", host + 'storeCheckout?' + params.toString(), false);
            req.withCredentials = true;
            req.send(JSON.stringify(checkoutDetails));
        }

        // now.do.whatever();
    });
});
