<?php
/**
 * Zagomail Connection Settings Page
 *
 * @package ZagomailPlugin
 */

defined( 'ABSPATH' ) || exit;

function zagomailShowConnectionSettings($validPermalinks)
{
    $btnClass = '';
    if (!$validPermalinks) {
        $btnClass = 'class="disabled"';
    }
    $urlParams = zagomailGetInstallUrlParams();
    $loginUrl = zagomailGetLoginUrl($urlParams);
    $registrationUrl = zagomailGetSignupUrl($urlParams);
    ?>
    <div class="connection-info-container">
        <div class="connection-content-left">
            <p class="title-text">Welcome to ZagoMail</p>
            <p class="sub-title-text">Send personalized and automated emails, collect subscribers, and turn 1st-time visitors into lifelong customers.</p>
            <div class="connection-btns">
                <a target="_blank" href="<?php echo $loginUrl; ?>" <?php echo $btnClass; ?>>
                    <button id="connect-your-account" class="connect-account-btn">Link account</button>
                </a>
                <a target="_blank" href="<?php echo $registrationUrl; ?>" <?php echo $btnClass; ?>>
                    <button id="create-new-account" class="create-account-btn">Register new account</button>
                </a>
            </div>
            <a target="_blank" href="https://kb.zagomail.com/en/articles/4681148-woocomerce-integration" class="zm-link">
                Check out the guide how to integrate with ZagoMail <img src="<?php echo ZAGO_LINK_ICON; ?>">
            </a>
        </div>
        <div class="connection-content-right">
            <img class="connection-image" src="<?php echo esc_url( plugin_dir_url( __NAMESPACE__ ) ) . 'zago-wordpress/assets/img/connection.png'; ?>">
        </div>
    </div>
    <script type="text/javascript">
        (function(){
            const connectYourAccountButton = document.getElementById('connect-your-account')
            const createNewAccountButton = document.getElementById('create-new-account')
            let interval

            function waitUntilAPIKeyAndRefresh() {
                if (interval) {
                    return
                }

                interval = setInterval(async () => {
                    fetch("<?php echo esc_url( home_url( '/wp-json/zagomail/v1/connected' ) ); ?>").then(r => r.json()).then(connected => {
                        if (!connected) {
                            return
                        }
                        clearInterval(interval)
                        location.reload()
                        connectYourAccountButton.removeEventListener('click', waitUntilAPIKeyAndRefresh)
                        createNewAccountButton.removeEventListener('click', waitUntilAPIKeyAndRefresh)
                    })
                }, 1000)
            }

            connectYourAccountButton.addEventListener('click', waitUntilAPIKeyAndRefresh)
            createNewAccountButton.addEventListener('click', waitUntilAPIKeyAndRefresh)
        })()
    </script>
    <?php
}

function zagomailGetInstallUrlParams() {
    $token = get_option('zago_connect_token', '');

    if (empty($token)) {
        $token = hash('sha256', uniqid('', true));
        update_option('zago_connect_token', $token);
    }

    return [
        'token' => $token,
        'storeUrl' => home_url(),
        'storeCurrency' => 'USD',
        'wcUserId' => get_current_user_id(),
        'type' => 'wordpress',
    ];
}

function zagomailGetLoginUrl(array $urlParams) {
    return esc_url(ZAGO_LOGIN_URL . '?' . http_build_query($urlParams));
}

function zagomailGetSignupUrl(array $urlParams) {
    $urlParams['utm_source'] = 'woocommerce_plugin';
    $urlParams['utm_medium'] = 'utm_medium';

    return esc_url(ZAGO_SIGNUP_URL . '?' . http_build_query($urlParams));
}
