<?php
defined('ABSPATH') || exit;

class Zago_Wp_Manager
{
    public $forms = [];

    public function __construct()
    {
        /*Declare plugin's settings page*/
        add_action( 'admin_menu', 'zago_woocommerce_menu' );

        function zago_woocommerce_menu() {
            $page_title = 'Zagomail for Woocommerce';
            $menu_title = 'Zagomail';
            $capability = 'manage_options';
            $menu_slug  = ZAGO_SETTINGS_PAGE;
            $function   = 'zago_show_settings_page';
            $icon_url   = plugin_dir_url( __DIR__ ) . 'assets/img/zago-icon.png';

            $position = 2;

            add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );
            add_submenu_page( $menu_slug, __( 'General' ), __( 'General' ), $capability, $menu_slug, $function );
//    add_submenu_page( $menu_slug, __( 'Logs' ), __( 'Logs' ), $capability, ZAGO_LOGS_PAGE, 'zago_show_logs' );
            if ( get_option( 'zago_api_key', null ) !== null ) {
                add_submenu_page(
                    $menu_slug,
                    __( 'Sync' ),
                    __( 'Sync' ),
                    $capability,
                    ZAGO_SYNC_PAGE,
                    'zago_show_sync'
                );
            }
        }

        add_action( 'admin_enqueue_scripts', 'zago_admin_assets' );
        function zago_admin_assets() {
            // phpcs:disable WordPress.Security.NonceVerification
            if (!empty($page = $_GET['page']) && zago_is_settings_page($page)) {
                wp_enqueue_style(
                    'zago-admin.css',
                    plugin_dir_url( __DIR__ ) . 'assets/css/zago-admin.css?' . time()
                );
                wp_enqueue_style( 'roboto.css', plugin_dir_url( __FILE__ ) . 'assets/fonts/roboto/roboto.css?' . time() );
            }
            // phpcs:enable
        }

        function zago_is_settings_page($page)
        {
            return in_array($page, [ZAGO_SETTINGS_PAGE, ZAGO_SYNC_PAGE, ZAGO_LOGS_PAGE], true);
        }

        add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'add_zago_settings_link' );
        function add_zago_settings_link( $links ) {
            $link = '<a href="' . admin_url( 'admin.php?page=' . ZAGO_SETTINGS_PAGE ) . '">' . __( 'Settings' ) . '</a>';
            array_unshift( $links, $link );

            return $links;
        }

        add_shortcode('zagomail', [$this, 'zago_render_form']);
    }

    public function zago_render_form($atts, $content): string
    {
        global $forms;

        $response = '';
        $params = shortcode_atts(
            ['form' => ''],
            $this->zago_sanitize_attributes($atts),
            'form'
        );


        if (!empty($params['form'])) {
            $formID = (int)$params['form'];
            $form = $this->zago_get_form_data($formID);
            if (!empty($form['formData'])) {
                $customerUID = $form['customer_uid'];

                if ($form['formData']['style'] == 'Inline') {
                    $response = <<<HTML
<!-- ZagoMail Form Embedding Code -->
<div class="zg-form-embed"
     data-account="{$customerUID}"
     data-form="{$formID}">
</div>
<script type="text/javascript">
(function(z,a,g,o) { var o=z.createElement(a); var _=z.getElementsByTagName(a)[0];
    o.async=1; o.src=g+'?v='+(~~(new Date().getTime()/1000000)); _.parentNode.insertBefore(o,_);
}) (document, 'script', 'https://app.zagomail.com/forms/embed.js');
</script>
<!-- End ZagoMail Form Embedding Code -->
HTML;
                } else {
                $response = <<<HTML
<!-- ZagoMail Form Embedding Code -->
<script type="text/javascript">
let body = document.querySelector('body');
let d = document.createElement('DIV');
d.classList.add('zg-form-embed');
d.setAttribute('data-account', '{$customerUID}');
d.setAttribute('data-form', '{$formID}');
body.appendChild(d);
(function(z,a,g,o) { var o=z.createElement(a); var _=z.getElementsByTagName(a)[0];
    o.async=1; o.src=g+'?v='+(~~(new Date().getTime()/1000000)); _.parentNode.insertBefore(o,_);
}) (document, 'script', 'https://app.zagomail.com/forms/embed.js');
</script>
<!-- End ZagoMail Form Embedding Code -->
HTML;
                }
            }
        }

        return $response;
    }

    public function zago_sanitize_attributes($attributes) {

        if (!is_array($attributes)) {
            return $attributes;
        }

        foreach ($attributes as $key => $value ) {
            if (is_array($value)) {
                continue;
            }

            $attributes[$key] = wp_strip_all_tags($value);
        }

        return $attributes;

    }

    public function get_zago_token_wp()
    {
        return get_option('zago_api_public_key', '');
    }

//    public function handleOrderStatusChanged($order_id, $checkout = null) {
//        global $woocommerce;
//        $order = new WC_Order($order_id);
//        $checkSetting = get_option('arhive-call-status');
//        $orderData = $order->get_data();
////        if ($orderData['status'] == 'completed') {
//        $this->apiSendOrderData($order_id);
////        }
////        if (isset($checkSetting) && $checkSetting !='' && ('wc-'.$orderData['status'] == $checkSetting)) {
////            $this->ARHiveWooCommerceCall($order_id);
////        }
//    }
//
//    public function apiSendOrderData($orderId) {
//        $order = new WC_Order($orderId);
//        $items = $order->get_items();
//        $userFirstName = '';
//        $userLastName = '';
//        $orderItems = [];
//        foreach ($items as $item) {
//            $itemData = $item->get_data();
//            $productId = $itemData['product_id'];
//
//            $product = $item->get_product();
//            $image = wp_get_attachment_url($product->get_image_id());
//            $price = floatval($product->get_price());
//
//            $orderItems[] = [
//                'id' => $itemData['product_id'],
//                'name' => $itemData['name'],
//                'quantity' => $itemData['quantity'],
//                'price' => $price,
//                'total' => $itemData['total'],
//                'image' => $image,
//            ];
//        }
//        $data = $order->get_data();
//        $data['line_items'] = $orderItems;
//        $this->updateCheckout($data);
////        $arhiveAutoResponderName = get_post_meta($productId, 'responder-name', true);
////        if($arhiveAutoResponderName ==''){
////            $default_autoresponder_settings = $this->ARHiveWooCommerceGetSettings('arhiveWooCommerce-default');
////            $arhiveAutoResponderName = isset($default_autoresponder_settings['responder-name'])?$default_autoresponder_settings['responder-name']:"";
////            $arhiveListName = isset($default_autoresponder_settings['campaign-list-id'])?$default_autoresponder_settings['campaign-list-id']:"";
////        }else{
////            $arhiveAutoResponderName = get_post_meta($productId, 'responder-name', true);
////            $arhiveListName = get_post_meta($productId, 'campaign-id', true);
////        }
////
////        $userEmail = get_post_meta($orderId, '_billing_email', true);
////        $userFirstName = get_post_meta($orderId, '_billing_first_name', true);
////        $userLastName = get_post_meta($orderId, '_billing_last_name', true);
////        $datas = array(
////            'userEmail' => $userEmail,
////            'userFirstName' => $userFirstName,
////            'userLastName' => $userLastName,
////            'responderName' => $arhiveAutoResponderName,
////            'responderId' => $arhiveListName,
////        );
////
////        $this->ARHiveWooCommerceAddContectInAutoResponder($datas);
//    }
//
//    private function updateCheckout($data)
//    {
//        $token = $this->getToken();
//        $this->sendDataToAPI(ZAGO_APP_URL . '/site/wchook', $token, 'POST', $data);
//    }

    public function unlink_zago_account_wp()
    {
        $token = $this->get_zago_token_wp();
        $this->zago_send_api_request(ZAGO_APP_URL . '/site/wchook', [
            'publicKey' => $token,
            'unlink_account' => 1
        ]);
    }

//    public function getFormsList(): array
//    {
//        $token = $this->getToken();
//        $formsJson = $this->sendDataToAPI(ZAGO_API_URL . '/forms/get-forms', $token, 'POST', ['publicKey' => $token]);
//
//        $response = json_decode($formsJson, true);
//        if (empty($response)) {
//            return [];
//        }
//
//        $forms = [];
//        if (!empty($response['formData'])) {
//            foreach ($response['formData'] as $formData) {
//                $forms[$formData['forms_id']] = $formData['title'];
//            }
//        }
//
//        return $forms;
//    }

    public function zago_get_form_data(int $id): array
    {
        $token = $this->get_zago_token_wp();
        $data = array(
            'publicKey' => $token,
            'formID' => $id,
        );
        return $this->zago_send_api_request( ZAGO_API_URL . '/forms/get-form', $data );
    }

    public function zago_send_api_request( string $url, array $data ): array
    {
        $args = array(
            'body'        => json_encode($data),
            'sslverify'   => false,
            'timeout'     => '15',
            'redirection' => '15',
            'httpversion' => '1.1',
            'blocking'    => true,
            'headers'     => array(
                'Content-type' => 'application/json',
                'Accept' => 'application/json'
            ),
            'cookies'     => array(),
        );

        $response_data = null;
        $response = wp_remote_post( $url, $args );
        if ( is_wp_error( $response ) ) {
            return ['Ошибка!' => $response->get_error_message()];
        }
        $response_code = wp_remote_retrieve_response_code( $response );
        if ( $response_code === 200 ) {
            $response_json = wp_remote_retrieve_body( $response ) ;
            $response_data = json_decode($response_json, true);
        }

        if (empty($response_data)) {
            return [];
        }

        return $response_data;
    }

    public function sendDataToAPI($url, $token = null, $type = 'GET', $postData = null)
    {
        $response = null;

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $type);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        if (!empty($postData)) {
            if (!empty($token)) {
                $postData['apiKey'] = $token;
            }
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($postData));
        }

        $headers = [];
        $headers[] = 'Content-Type: application/json';
        $headers[] = 'User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:95.0) Gecko/20100101 Firefox/95.0';

        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

        $result = curl_exec($ch);

        $http_code = curl_getinfo($ch, CURLINFO_RESPONSE_CODE);
        if (curl_errno($ch)) {
            error_log('API request error: ' . curl_error($ch));
        }

        if ($http_code >= 200 && $http_code < 300) {
            $response = $result;
        } else {
            error_log("Error response from ZagoMail API: $url\n" . print_r($result, true));
            $data = json_decode($result, true);
            if (!empty($data['errors'])) {
                $errors = print_r($data['errors'], true);
            } else {
                $errors = print_r($data, true);
            }
            error_log(sprintf("Server status %d. Message: %s", $http_code, $errors));
        }
        curl_close($ch);

        return $response;
    }
}
