<?php
/**
 * Zagomail Settings Page
 *
 * @package ZagomailPlugin
 */

defined( 'ABSPATH' ) || exit;

/**
 * Function renders the plugin settings page
 */
function zago_show_settings_page()
{
    if (!zagoHandleSettingsPageActions_WP()) {
        return;
    }

    if (!checkAPIConnected()) {
        showZagoConnection();
        return;
    }

    showSettings();
}

/**
 * Function checks if ZagoMail API is already connected
 * @return bool
 */
function checkAPIConnected(): bool
{
    return !(empty(get_option( 'zago_api_public_key')) || empty(get_option('zago_api_private_key')));
}

function showZagoConnection()
{
    ?>
    <div class="zm-container">
        <?php
        $permalinksValid = Zagomail_Helper::validate_permalinks();
        if (!$permalinksValid) {
            zagomailShowPermalinkNotice();
        }

        $zagoNotice = get_option('zago_notice_message');
        if (!empty($zagoNotice)) {
            zago_show_notice($zagoNotice);
            delete_option('zago_notice_message');
        }

        zagomailShowConnectionSettings($permalinksValid);
        ?>
    </div>
    <?php
    zagomailPluginVersion();
}

function displayZagomailLogo()
{
    ?>
    <div class="zagomail-logo">
        <a href="<?php echo esc_url(ZAGO_APP_URL); ?>" target="_blank">
            <img src="<?php echo ZAGO_PLUGIN_URL . 'assets/img/logo.webp'; ?>">
        </a>
    </div>
    <?php
}

function zagomailPluginVersion()
{
    ?>
    <div class="plugin-version">
        <p>
            Zagomail Plugin for WordPress - v.<?php echo esc_html(ZAGO_PLUGIN_VERSION); ?>
        <p>
    </div>
    <?php
}

function displayWCNotInstalled()
{
    ?>
    <div class="settings-page">
        <?php
        displayZagomailLogo();
        ?>
        <div class="settings-section">
            <div class="zm-notice">
                <div class="zm-content">
                    <img src="<?php echo ZAGO_WARNING_ICON; ?>">
                    <div class="zm-text">
                        <p>Zagomail plugin works in connection with WooCommerce. Please, make sure you have <a href=" <?php echo esc_url( network_admin_url( 'plugin-install.php?s=woocommerce&tab=search&type=term' ) ); ?>">WooCommerce</a> installed and activated</p>
                    </div>
                </div>
            </div>
        </div>
        <?php
        zagomailPluginVersion();
        ?>
    </div>
    <?php
}

function showSettings()
{
    ?>
    <div class="zm-container">
        <?php
        showSettingsPage();
        ?>
    </div>
    <?php
    zagomailPluginVersion();
}
