<?php
/**
 * Plugin Name: Zagomail E-mail marketing & automations
 * Plugin URI: https://www.zagomail.com
 * Description: This plugin connects your WordPress site with your Zagomail account.
 * Version: 1.0.1
 * Developer: Zagomail
 * Developer URI: https://www.zagomail.com
 *
 * Requires PHP: 7.0
 *
 * Copyright: © 2023 Zagomail
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package ZagomailPlugin
 */

defined('ABSPATH') || exit;

define('ZAGO_PLUGIN_VERSION', '1.0.1');
define('ZAGO_SETTINGS_PAGE', 'zago-wordpress');
define('ZAGO_LOGS_PAGE', 'zago-logs');
define('ZAGO_SYNC_PAGE', 'zago-sync');
define('ZAGO_APP_URL', 'https://app.zagomail.com');
//define('ZAGO_APP_URL', 'http://zago.test/app');
define('ZAGO_API_URL', 'https://api.zagomail.com');
define('ZAGO_PLUGIN_URL', esc_url(plugin_dir_url( __FILE__ )));
define('ZAGO_PLUGIN_INSTALL_URL', '/wp-json/zagomail/v1/connect');
define('ZAGO_LOGIN_URL', ZAGO_APP_URL .'/user/guest/index');
define('ZAGO_SIGNUP_URL', ZAGO_APP_URL . '/user/guest/register');

/* icons & logos */
define('ZAGO_WARNING_ICON', ZAGO_PLUGIN_URL . 'assets/img/warning-icon.svg');
define('ZAGO_LINK_ICON', ZAGO_PLUGIN_URL . 'assets/img/external-link-icon.svg');

require_once 'zago-woocommerce-settings.php';
require_once 'zago-woocommerce-helper.php';

require_once 'settings/settings-page.php';
require_once 'settings/connection-settings.php';
require_once 'shared/notice-view.php';
require_once 'settings/permalink-notice.php';
require_once 'shared/zago-wp-manager.php';

$manager = new Zago_Wp_Manager();

add_action('rest_api_init', function () {

    register_rest_route('zagomail/v1/connect', '/(?P<key>\w+)', array(
        'methods' => 'POST',
        'callback' => 'connectZagoAccount',
    ));

    register_rest_route('zagomail/v1', '/connected', array(
        'methods' => 'GET',
        'callback' => 'registerRestConnected',
    ));

});

/**
 * Function saves ZagoMail credentials into options
 * @param $data
 * @return array
 */
function connectZagoAccount($data)
{

    $responseData = [
        'success' => false,
        'message' => 'Error connecting the store',
    ];

    $token = get_option('zago_connect_token', '');
    if ($data['key'] == $token) {
        update_option('zago_api_public_key', $data['publicKey']);
        update_option('zago_api_private_key', $data['privateKey']);

        $responseData = [
            'success' => true,
            'message' => 'Store connected successfully',
        ];
    }

    return $responseData;
}

function registerRestConnected()
{
    $publicKey = get_option( 'zago_api_public_key');
    $privateKey = get_option('zago_api_private_key');

    return !empty($publicKey) && !empty($privateKey);
}
